[Solar-svn] Revision 3139

pmjones at solarphp.com pmjones at solarphp.com
Wed Apr 30 17:27:25 CDT 2008


Solar_Sql_Model_Record: [CHG] In method form(), if no $cols are passed, now uses all fetch cols and calculate cols (previously would use all table cols, and no others).


Modified: trunk/Solar/Sql/Model/Record.php
===================================================================
--- trunk/Solar/Sql/Model/Record.php	2008-04-29 13:55:49 UTC (rev 3138)
+++ trunk/Solar/Sql/Model/Record.php	2008-04-30 22:27:23 UTC (rev 3139)
@@ -1360,8 +1360,7 @@
      * this record).
      * 
      * @param array $cols An array of column property names to include in
      * the form.  If empty, uses all columns except the "special" ones
      * (primary, created, updated, inherit, and sequence).
      * 
      * @return Solar_Form
      * 
@@ -1370,7 +1369,10 @@
     {
         // use all columns?
         if (empty($cols)) {
-            $cols = '*';
+            $cols = array_merge(
+                array_keys($this->_model->table_cols),
+                $this->_model->calculate_cols
+            );
         }
         
         // put into this array in the form
@@ -1360,8 +1360,7 @@
      * 
      * @param array $cols An array of column property names to include in
-     * the form.  If empty, uses all columns except the "special" ones
-     * (primary, created, updated, inherit, and sequence).
+     * the form.  If empty, uses all fetch columns and all calculate columns.
      * 
      * @return Solar_Form




More information about the Solar-svn mailing list